abstochkin API documentation
Description: Agent-based (or Particle-based) Stochastic Kinetics.

# Package `abstochkin`

Agent-based (or Particle-based) Stochastic Kinetics.

Expand source code

    """ Agent-based (or Particle-based) Stochastic Kinetics. """

    #  Copyright (c) 2023, Alex Plakantonakis.
    #
    #  This program is free software: you can redistribute it and/or modify
    #  it under the terms of the GNU General Public License as published by
    #  the Free Software Foundation, either version 3 of the License, or
    #  (at your option) any later version.
    #
    #  This program is distributed in the hope that it will be useful,
    #  but WITHOUT ANY WARRANTY; without even the implied warranty of
    #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    #  GNU General Public License for more details.
    #
    #  You should have received a copy of the GNU General Public License
    #  along with this program.  If not, see <http://www.gnu.org/licenses/>.

    from .base import AbStochKin

    __version__ = '0.1.0'
    __license__ = "GPL-3.0"

## Sub-modules

`abstochkin.agentstatedata`

  Class for storing the state of all agents of a certain species during an AbStochKin simulation.

`abstochkin.base`

  Base class, AbStochKin, for initializing and storing all data for performing stochastic simulations using the Agent-based Kinetics method. A …

`abstochkin.de_calcs`

  Perform deterministic calculations on a set of processes. Construct the ordinary differential equations (ODEs) describing the system and obtain a …

`abstochkin.graphing`

  Graphing for AbStochKin simulations.

`abstochkin.het_calcs`

  Some functions for calculating metrics of population heterogeneity.

`abstochkin.process`

  Define a process of the form Reactants -> Products.

`abstochkin.simulation`

  Perform an Agent-based Kinetics simulation …

`abstochkin.utils`

  Some utility functions on generating random number streams, measuring a function's runtime, calculating a statistic measuring the goodness of fit when …